@@ -314,14 +314,13 @@ will result in following node:
 		   (plist-get info :title))
 		  (t (error "Shouldn't come here."))))
 	 (element-contents (org-element-contents element))
-	 (section (assoc 'section element-contents))
+	 (section (assq 'section element-contents))
 	 (section-contents
-	  (let* ((translations
-		  (nconc (list (cons 'section
-				     (lambda (section contents info)
-				       contents)))
-			 (plist-get info :translate-alist))))
-	    (org-export-data-with-translations section translations info)))
+	  (let ((backend (org-export-create-backend
+			  :parent (org-export-backend-name
+				   (plist-get info :back-end))
+			  :transcoders '((section . (lambda (e c i) c))))))
+	    (org-export-data-with-backend section backend info)))
 	 (itemized-contents-p (let ((first-child-headline
 				     (org-element-map element-contents
 					 'headline 'identity info t)))
@@ -519,17 +518,10 @@ file-local settings.
 Return output file's name."
   (interactive)
   (let* ((extension (concat ".mm" ))
-	 (file (org-export-output-file-name extension subtreep)))
-    (if async
-	(org-export-async-start
-	    (lambda (f) (org-export-add-to-stack f 'freemind))
-	  (let ((org-export-coding-system 'utf-8))
-	    `(expand-file-name
-	      (org-export-to-file
-	       'freemind ,file ,subtreep ,visible-only ,body-only ',ext-plist))))
-      (let ((org-export-coding-system 'utf-8))
-	(org-export-to-file
-	 'freemind file subtreep visible-only body-only ext-plist)))))
+	 (file (org-export-output-file-name extension subtreep))
+	 (org-export-coding-system 'utf-8))
+    (org-export-to-file 'freemind file
+      async subtreep visible-only body-only ext-plist)))
 
 (provide 'ox-freemind)
 
