@@ -315,7 +315,8 @@ If the task has an end part, also demote it."
      ((= end start))
      ;; Inlinetask was folded: expand it.
      ((get-char-property (1+ start) 'invisible)
-      (org-show-entry))
+      (outline-flag-region start end nil)
+      (org-cycle-hide-drawers 'children))
      (t (outline-flag-region start end t)))))
 
 (defun org-inlinetask-remove-END-maybe ()
